| Title: | Ionization efficiency prediction and quantification of unidentified chemicals |
|---|---|
| Description: | MS2Quant harvests pre-trained xgbTree algorithm-based ionization efficiency prediction model. Using strucutral information (SMILES) or predicted fingerprints calculated with SIRIUS+CSI_FingerID software, ionization efficiency can be predicted. If calibrants have been measured together with suspects subject to quantification, predicted ionization efficiencies can be converted into measurement-specific response factors and concentration of unknown chemcals can be estimated. |
| Authors: | Helen Sepman [aut, cre] (ORCID: <https://orcid.org/0000-0002-8222-9962>) |
| Maintainer: | Helen Sepman <[email protected]> |
| License: | `use_mit_license()`, `use_gpl3_license()` or friends to pick a license |
| Version: | 1.1.0 |
| Built: | 2026-05-27 06:49:55 UTC |
| Source: | https://github.com/kruvelab/MS2Quant |
This function calculates isotopic abundance for a chemical based on SMILES notation. This number can later be used as a coefficient to multiply the area corresponding to a monoisotopic ion.
isotopedistribution(smiles)isotopedistribution(smiles)
smiles |
SMILES notation of the compound |
isotopic abundance coefficient
isotopedistribution("CN1C=NC2=C1C(=O)N(C(=O)N2C)C")isotopedistribution("CN1C=NC2=C1C(=O)N(C(=O)N2C)C")
This function calculates the linear regression parameters from specified x and y values. Additionally, it checks the linearity based on residuals. In case there exists a residual with absolute value higher than 10, the highest value x-y point will be removed and new linear regression is generated without it. At least 5 datapoints have to remain.
linear_regression(y, x, remove_lowest_conc = FALSE)linear_regression(y, x, remove_lowest_conc = FALSE)
y |
y-values of the data corresponding to x-values |
x |
x-values of the data |
linear regression parameters (slope and intercept) as a list